@@ -26,7 +26,7 @@ pub fn json_dir_to_root<P : AsRef<Path>>(dir_path : P, validation : bool) -> Cor
     json_dir_to_root_with_hash(dir_path, validation).map(|(root,_)| root)
 }
 
-pub fn json_dir_to_archive<P : AsRef<Path>>(dir_path : P) -> CoreResult<DocchiArchive>{
+pub(crate) fn json_dir_to_archive<P : AsRef<Path>>(dir_path : P) -> CoreResult<DocchiArchive>{
     let data = read_archive_data_from_directory(dir_path, &JSON_ARC_OPT, json_file_to_rust)?;
     for (_name,item) in data.btree(){
         if let Err(e) = item.converted_data(){
